/* This is JavaScript code: it tells the web browser what to do when controls are clicked.
   Part of what web browsers can do today is to make network connections to other web servers;
   that’s what this particular example does. */
(() => {
  let showLoadingMessage = whichMessage => $(".loading." + whichMessage).removeClass("d-none");
  let hideLoadingMessage = whichMessage => $(".loading." + whichMessage).addClass("d-none");

  let jsonToString = json => JSON.stringify(json, null, 2);
  let xmlToString = xml => new XMLSerializer().serializeToString(xml);


  $("button.uniprot").click(() => {
    showLoadingMessage("uniprot");

    // Crib sheet: http://www.uniprot.org/help/api_retrieve_entries
    $.get("http://www.uniprot.org/uniprot/P10961.xml").done(response => {
      console.log("UniProt", response);
      $("textarea.uniprot").val(xmlToString(response));
      hideLoadingMessage("uniprot");
    });
  });

  $("button.sgd").click(() => {
    showLoadingMessage("sgd");

    // Crib sheet: These are for FlyMine but they use the same "engine." The only difference is the server and path.
    // - http://iodocs.apps.intermine.org/flymine/docs#/ws-quick-search/GET/search
    // - http://iodocs.apps.intermine.org/flymine/docs#/ws-data/GET/data/:type
    $.getJSON("https://yeastmine.yeastgenome.org/yeastmine/service/data/Gene?id=1020637").done(response => {
      console.log("SGD", response);
      $("textarea.sgd").val(jsonToString(response));
      hideLoadingMessage("sgd");
    });
  });
})();
